% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RSI.R
\name{RSI}
\alias{RSI}
\title{Relative Strength Index}
\usage{
RSI(price, n = 14, maType, ...)
}
\arguments{
\item{price}{Price series that is coercible to xts or matrix.}

\item{n}{Number of periods for moving averages.}

\item{maType}{Either:
\enumerate{
  \item A function or a string naming the function to be called.
  \item A \emph{list} with the first component like (1) above, and
    additional parameters specified as \emph{named} components.
    See Examples.
}}

\item{\dots}{Other arguments to be passed to the \code{maType} function in
case (1) above.}
}
\value{
A object of the same class as \code{price} or a vector (if
\code{try.xts} fails) containing the RSI values.
}
\description{
The Relative Strength Index (RSI) calculates a ratio of the recent upward
price movements to the absolute price movement.  Developed by J. Welles
Wilder.
}
\details{
The RSI calculation is \code{RSI = 100 - 100 / ( 1 + RS )}, where \code{RS}
is the smoothed ratio of 'average' gains over 'average' losses.  The
'averages' aren't true averages, since they're divided by the value of
\code{n} and not the number of periods in which there are  gains/losses.
}
\note{
The RSI is usually interpreted as an overbought/oversold (over 70 /
below 30) indicator.  Divergence with price may also be useful.  For example,
if price is making new highs/lows, but RSI is not, it could indicate a
reversal.

You can calculate a stochastic RSI by using the function \code{\link{stoch}}
on RSI values.
}
\examples{

 data(ttrc)
 price <- ttrc[,"Close"]

 # Default case
 rsi <- RSI(price)

 # Case of one 'maType' for both MAs
 rsiMA1 <- RSI(price, n=14, maType="WMA", wts=ttrc[,"Volume"])

 # Case of two different 'maType's for both MAs
 rsiMA2 <- RSI(price, n=14, maType=list(maUp=list(EMA),maDown=list(WMA)))


}
\references{
The following site(s) were used to code/document this
indicator:
\cr Relative Strength Index:\cr
\url{https://www.fmlabs.com/reference/RSI.htm}\cr
\url{https://www.metastock.com/Customer/Resources/TAAZ/?p=100}\cr
\url{https://www.linnsoft.com/techind/relative-strength-index-rsi}\cr
\url{https://school.stockcharts.com/doku.php?id=technical_indicators:relative_strength_index_rsi}\cr
\cr Stochastic RSI:\cr
\url{https://www.fmlabs.com/reference/StochRSI.htm}\cr
\url{https://school.stockcharts.com/doku.php?id=technical_indicators:stochrsi}\cr
}
\seealso{
See \code{\link{EMA}}, \code{\link{SMA}}, etc. for moving average
options; and note Warning section.  See \code{\link{CMO}} for a variation on
RSI.
}
\author{
Joshua Ulrich
}
\keyword{ts}
