% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ZigZag.R
\name{ZigZag}
\alias{ZigZag}
\alias{zigzag}
\title{Zig Zag}
\usage{
ZigZag(HL, change = 10, percent = TRUE, retrace = FALSE, lastExtreme = TRUE)
}
\arguments{
\item{HL}{Object that is coercible to xts or matrix and contains either a
High-Low price series, or a Close price series.}

\item{change}{Minimum price movement, either in dollars or percent (see
\code{percent}).}

\item{percent}{Use percentage or dollar change?}

\item{retrace}{Is \code{change} a retracement of the previous move, or an
absolute change from peak to trough?}

\item{lastExtreme}{If the extreme price is the same over multiple periods,
should the extreme price be the first or last observation?}
}
\value{
A object of the same class as \code{HL} or a vector (if
\code{try.xts} fails) containing the Zig Zag indicator.
}
\description{
Zig Zag higlights trends by removing price changes smaller than \code{change}
and interpolating lines between the extreme points.
}
\details{
The Zig Zag is non-predictive.  The purpose of the Zig Zag is filter noise
and make chart patterns clearer.  It's more a visual tool than an indicator.
}
\note{
If High-Low prices are given, the function calculates the max/min using
the high/low prices.  Otherwise the function calculates the max/min of the
single series.
}
\section{Warning}{
 The last value of the ZigZag indicator is unstable (i.e.
unknown) until the turning point actually occurs. Therefore this indicator
isn't well-suited for use for systematic trading strategies.
}

\examples{

 ## Get Data and Indicator ##
 data(ttrc)
 zz <- ZigZag( ttrc[,c("High", "Low")], change=20 )

}
\references{
The following site(s) were used to code/document this
indicator:\cr
\url{https://www.fmlabs.com/reference/default.htm?url=ZigZag.htm}\cr
\url{https://www.linnsoft.com/techind/zig-zag-indicator-zig-zzo}\cr
\url{https://www.linnsoft.com/techind/zig-zag-oscillator-indicator-zzo}\cr
\url{https://www.metastock.com/Customer/Resources/TAAZ/?p=127}\cr
\url{https://school.stockcharts.com/doku.php?id=technical_indicators:zigzag}\cr
}
\author{
Joshua Ulrich
}
\keyword{ts}
